@@ -34,8 +34,11 @@ function (x, censored, method = "mle", censoring.side = "left",
     if (length(unique(x.no.cen)) < 2) 
         stop("'x' must contain at least 2 non-missing, uncensored, distinct values.")
     N <- length(x)
-    method <- match.arg(method, c("mle", "qmvue", "bcmle", "impute.w.qq.reg", 
-        "impute.w.qq.reg.w.cen.level", "impute.w.mle", "half.cen.level"))
+    method <- match.arg(method, c("mle", "qmvue", "bcmle", "rROS", 
+        "impute.w.qq.reg", "impute.w.qq.reg.w.cen.level", "impute.w.mle", 
+        "half.cen.level"))
+    if (method == "rROS") 
+        method <- "impute.w.qq.reg"
     censoring.side <- match.arg(censoring.side, c("left", "right"))
     T1 <- unique(x[censored])
     if (length(T1) > 1) 
@@ -91,7 +94,7 @@ function (x, censored, method = "mle", censoring.side = "left",
     }
     method.string <- switch(method, mle = "MLE", qmvue = "Quasi-MVUE", 
         bcmle = "Bias-corrected MLE", impute.w.qq.reg = paste("Imputation with\n", 
-            space(33), "Q-Q Regression (ROS)", sep = ""), impute.w.qq.reg.w.cen.level = paste("Imputation with\n", 
+            space(33), "Q-Q Regression (rROS)", sep = ""), impute.w.qq.reg.w.cen.level = paste("Imputation with\n", 
             space(33), "Q-Q Regression (ROS)\n", space(33), "with Censoring Level", 
             sep = ""), impute.w.mle = "Imputation with MLE", 
         half.cen.level = "Half Censoring Level")
